@@ -33,7 +33,7 @@ count=1
 while (keep.clustering) {   #loop until we figure out we should stop
 #find similiarities
  #we will do most of the work on a copy of the r.mat
-cluster.stats <- cluster.cor(clusters,r.mat,FALSE,digits=9,SMC=ICLUST.options$SMC)  
+cluster.stats <- cluster.cor(clusters,r.mat,FALSE,SMC=ICLUST.options$SMC)  
 sim.mat <- cluster.stats$cor    #the correlation matrix
 diag(sim.mat) <- 0   #we don't want 1's on the diagonal to mess up the maximum 
 
@@ -193,15 +193,15 @@ if (ICLUST.options$alpha>0) { #should we apply the alpha test?
 if (ICLUST.options$alpha.size < min(size1,size2)) {
   switch(ICLUST.options$alpha, {if (alpha < min(alpha1,alpha2)) {if (output>2) {print(
   paste ('do not combine ', cluster.names[max.row],"with", cluster.names[max.col],
-  'new alpha =', round (alpha,digits),'old alpha1 =',round( alpha1,digits),"old alpha2 =",round(alpha2,digits)))}
+  'new alpha =', alpha,'old alpha1 =', alpha1,"old alpha2 =",alpha2))}
 												test.alpha <- FALSE }},
   {if (alpha < mean(alpha1,alpha2)) {if (output>2) {print(paste ('do not combine ',
-  cluster.names[max.row],"with", cluster.names[max.col],'new alpha =', round (alpha,digits),
-  'old alpha1 =',round( alpha1,digits),"old alpha2 =",round(alpha2,digits)))}
+  cluster.names[max.row],"with", cluster.names[max.col],'new alpha =',alpha,
+  'old alpha1 =',alpha1,"old alpha2 =",alpha2))}
 												test.alpha <- FALSE  }},
   {if (alpha < max(alpha1,alpha2)) {if (output>2) {print(paste ('do not combine ',
-  cluster.names[max.row],"with", cluster.names[max.col],'new alpha =', round (alpha,digits),
-  'old alpha1 =',round( alpha1,digits),"old alpha2 =",round(alpha2,digits)))}
+  cluster.names[max.row],"with", cluster.names[max.col],'new alpha =', alpha,
+  'old alpha1 =',alpha1,"old alpha2 =",alpha2))}
 												test.alpha <- FALSE  }}) #end switch  
   }   #end if options$alpha.size
   }
