@@ -1,13 +1,13 @@
-"ICLUST.sort"<- function (ic.load,cut=0,labels=NULL,keys=FALSE) {
+"ICLUST.sort"<- function (ic.load,cut=0,labels=NULL,keys=FALSE, clustsort=TRUE) {
      if(is.matrix(ic.load)) {loadings <- ic.load} else { loadings <- ic.load$loadings}
     
      nclust <- dim(loadings)[2]
      nitems <- dim(loadings)[1]
      loadings <- as.matrix(loadings)   #just in case there is just one cluster
      loadings <- unclass(loadings)     #to get around the problem of a real loading matrix
-     if(nclust > 1) {eigenvalue <- diag(t(loadings) %*% loadings)  #put the clusters into descending order by eigenvalue
+     if(nclust > 1) {eigenvalue <- diag(t(ic.load$pattern)%*% loadings)  #put the clusters into descending order by eigenvalue
                      evorder <- order(eigenvalue,decreasing=TRUE)
-                     loadings <- loadings[,evorder]
+                     if(clustsort) loadings <- loadings[,evorder]  #added the clustsort option 2011.12.22 until now had always sorted
                      }
     if (length(labels)==0) {
     var.labels <- rownames(loadings)} else {var.labels=labels}
@@ -41,7 +41,7 @@
     }
     if (first < nitems) loads[first:nitems,"cluster"] <- 0   #assign items less than cut to 0
       if(keys) {result <- list(sorted=loads,clusters=factor2cluster(loadings))} else  result <- list(sorted=loads)
-   #class(result) <- c("psych","iclust")
+   #class(result) <- c("psych","iclust")   #need to clean up print to make this work
    return(result)
 }
  #revised August 8, 2007 to add cluster keying option and to allow us to work with factor analysis output
