@@ -1,5 +1,5 @@
 "principal" <-
-function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, scores=FALSE,missing=FALSE,impute="median",oblique.scores=TRUE) {
+function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, covar=FALSE,scores=FALSE,missing=FALSE,impute="median",oblique.scores=TRUE,method="regression",...) {
    cl <- match.call()
    n <- dim(r)[2]
   
@@ -14,12 +14,13 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, scores=FALSE,
       				x.matrix[miss]<- item.means[miss[,2]]} else {
        				item.med   <- apply(x.matrix,2,median,na.rm=TRUE) #replace missing with medians
        				 x.matrix[miss]<- item.med[miss[,2]]}
-       				 }}
-      r <- cor(r,use="pairwise")  # if given a rectangular matrix, then find the correlations first
+       				 }} 
+       				 # 2011.12.21  added the covar option
+      if(!covar) {r <- cor(r,use="pairwise")} else r <- cov(r,use="pairwise")  # if given a rectangular matrix, then find the correlations or covariances first
              } else {
      				if(!is.matrix(r)) {  r <- as.matrix(r)}
      				 sds <- sqrt(diag(r))    #convert covariance matrices to correlation matrices
-                     r <- r/(sds %o% sds)  }  #added June 9, 2008
+                     if(!covar) r <- r/(sds %o% sds)  }  #added June 9, 2008
     if (!residuals) { result <- list(values=c(rep(0,n)),rotation=rotate,n.obs=n.obs,communality=c(rep(0,n)),loadings=matrix(rep(0,n*n),ncol=n),fit=0,fit.off=0)} else { result <- list(values=c(rep(0,n)),rotation=rotate,n.obs=n.obs,communality=c(rep(0,n)),loadings=matrix(rep(0,n*n),ncol=n),residual=matrix(rep(0,n*n),ncol=n),fit=0,fit.off=0)}
     eigens <- eigen(r)    #call the eigen value decomposition routine
     result$values <- eigens$values
@@ -28,6 +29,7 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, scores=FALSE,
    
    if(nfactors >0) {loadings <- loadings[,1:nfactors]} else {nfactors <- n}
    if (nfactors>1) {communalities <- rowSums(loadings^2)} else {communalities <- loadings^2 }
+   uniquenesses <- diag(r) - communalities # 2011.12.21 uniqueness is now found if covar is true
     names(communalities) <- colnames(r)    # 2009.02.10 Make sure this is a named vector -- correction by Gumundur Arnkelsson
    	
    
@@ -47,29 +49,32 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, scores=FALSE,
      Phi <- NULL
       if(rotate != "none") {if (nfactors > 1) {
   
-   	if (rotate=="varimax" | rotate== "Varimax" |rotate=="quartimax") { 
-   			rotated <- do.call(rotate,list(loadings))
+   	if (rotate=="varimax" |rotate=="Varimax" | rotate=="quartimax" | rotate =="bentlerT" | rotate =="geominT" |rotate =="bifactor" ||rotate =="targetT" ) { 
+   	if (!require(GPArotation)) {stop("I am sorry, to do these rotations requires the GPArotation package to be installed")}
+   	       #varimax is from the stats package, Varimax is from GPArotations
+   			rotated <- do.call(rotate,list(loadings,...))
    			loadings <- rotated$loadings
-   			 colnames(loadings) <- paste("RC",1:nfactors,sep='')
    			 Phi <- NULL} else { 
-     			if ((rotate=="promax")|(rotate=="Promax")) {pro <- Promax(loadings)
+   			
+     			if ((rotate=="promax")|(rotate=="Promax") ) {pro <- Promax(loadings)
      			                loadings <- pro$loadings
      			                Phi <- pro$Phi} else {
-     			if (rotate == "cluster") {loadings <- Varimax(loadings)$loadings           			
-								pro <- target.rot(loadings)
+     			if (rotate == "cluster") {loadings <- varimax(loadings)$loadings           			
+								pro <- target.rot(loadings,...)
      			              	loadings <- pro$loadings
-     			              	colnames(loadings) <- paste("TC",1:nfactors,sep='')
      			                Phi <- pro$Phi} else {
      			                     
-     			if (rotate =="oblimin"| rotate=="quartimin" | rotate== "simplimax") {
+     			if (rotate =="oblimin"| rotate=="quartimin" | rotate== "simplimax" | rotate =="geominQ"  | rotate =="bentlerQ" |rotate == "biquartimin" |rotate == "targetQ" |rotate == "TargetQ" ) {
      				if (!require(GPArotation)) {warning("I am sorry, to do these rotations requires the GPArotation package to be installed")
-     				Phi <- NULL} else { ob  <- do.call(rotate,list(loadings) )
+     				Phi <- NULL} else { ob  <- try(do.call(rotate,list(loadings,...) ))
+     				          if(class(ob)== as.character("try-error"))  {warning("The requested transformaton failed, Promax was used instead as an oblique transformation")
+     				                  ob <- Promax(loadings)}
+     				                 
      				loadings <- ob$loadings
-     				colnames(loadings) <- paste("TC",1:nfactors,sep='')
      				 Phi <- ob$Phi}
      		                             }
      	               }}}
-     	  
+    
      }}
    #just in case the rotation changes the order of the components, sort them by size of eigen value
    if(nfactors >1) {
@@ -97,6 +102,7 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, scores=FALSE,
     result$Phi <- Phi
     result$Call <- cl
     result$communality <- communalities
+    result$uniquenesses <- uniquenesses
     #result$stats <- stats
     result$R2 <- stats$R2
     result$objective <- stats$objective
@@ -116,8 +122,8 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, scores=FALSE,
                        Structure <- loadings %*% Phi} else {Structure <- loadings
                        }
     
-    if(scores) {result$scores <- factor.scores(scale(x.matrix),Structure)
-                result$weigths<- result$scores$weights
+    if(scores) {result$scores <- factor.scores(scale(x.matrix),Structure,method=method)  # method = method added Nov 20, 2011
+                result$weights<- result$scores$weights
                 result$scores <- result$scores$scores}
     return(result)
    }
@@ -131,4 +137,6 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, scores=FALSE,
   #modified Jan 19, 2009 to allow for promax rotations
   #modified May 15, 2009 to allow for singular matrices
   #correct August 25, 2009 to return result$values
-  #modified August 25 to return result$stats
\ No newline at end of file
+  #modified August 25 to return result$stats
+  #modified November 20, 2011 to allow multiple scoring approaches to give component scores
+  #modified December 21, 2011 to allow for finding the pc of covariances 
\ No newline at end of file
