@@ -40,6 +40,7 @@ if(!is.null(object$fn)) {fa <- TRUE}
  cat("\nThe Velicer MAP criterion achieves a minimum of ")
  vss.map <- round(max(object$map) ,digits) 
  cat(vss.map," with " ,which.min(object$map), " factors\n ") 
+ 
  }
  
 if(iclust) { cat("ICLUST (Item Cluster Analysis)") 
@@ -116,16 +117,19 @@ if(fa) {
    }
 
 
-    if(!is.null(object$rms)) {cat("\nThe root mean square of the residuals is ", round(object$rms,digits),"\n") }
+    if(!is.null(object$rms)) {cat("\nThe root mean square of the residuals (RMSA) is ", round(object$rms,digits),"\n") }
     if(!is.null(object$crms)) {cat("The df corrected root mean square of the residuals is ", round(object$crms,digits),"\n") }
     
    
-   	if(!is.null(object$TLI)) cat("\nTucker Lewis Index of factoring reliability = ",round(object$TLI,digits+1))}
+   	if(!is.null(object$TLI)) {cat("\nTucker Lewis Index of factoring reliability = ",round(object$TLI,digits+1))}
   
    	if(!is.null(object$RMSEA)) {cat("\nRMSEA index = ",round(object$RMSEA[1],digits+1), " and the", (1- object$RMSEA[4])*100,"% confidence intervals are ",round(object$RMSEA[2:3],digits+1))  }
    
-   	if(!is.null(object$BIC)) {cat("\nBIC = ",round(object$BIC,digits))
-
+   	if(!is.null(object$BIC)) {cat("\nBIC = ",round(object$BIC,digits))}
+  if(!is.null(object$Phi)) {
+   if(object$fn == "principal") {cat ("\n With component correlations of \n" ) } else {cat ("\n With factor correlations of \n" )}
+       colnames(object$Phi) <- rownames(object$Phi) <- colnames(object$loadings)
+       print(round(object$Phi,digits))}
 }
 
 
@@ -189,12 +193,29 @@ print(object$total,digits=digits)
            }
            
   if(irt.fa) {
-   cat("Item Response Analysis using Factor Analysis = ")
-   cat("\nCall: ")
+     cat("\nItem Response Theory using factor analysis with Call: ")
    print(object$Call)
-  print(round(object$coefficients,digits))
-  print(object$stats,digits)
-  }
+   
+ 	nfactors <- dim(object$fa$loadings)[2]
+    objective <- object$fa$criteria[1]
+     if(!is.null(objective)) {    cat("\nTest of the hypothesis that", nfactors, if (nfactors == 1)  "factor is" else "factors are", "sufficient.")
+    cat("\nThe degrees of freedom for the model is",object$fa$dof," and the objective function was ",round(objective,digits),"\n") 
+   	if(!is.na(object$fa$n.obs)) {cat("The number of observations was ",object$fa$n.obs, " with Chi Square = ",round(object$fa$STATISTIC,digits), " with prob < ", signif(object$fa$PVAL,digits),"\n")}
+  
+    if(!is.null(object$fa$rms)) {cat("\nThe root mean square of the residuals (RMSA) is ", round(object$fa$rms,digits),"\n") }
+    if(!is.null(object$fa$crms)) {cat("The df corrected root mean square of the residuals is ", round(object$fa$crms,digits),"\n") }
+    
+   
+   	if(!is.null(object$fa$TLI)) cat("\nTucker Lewis Index of factoring reliability = ",round(object$fa$TLI,digits+1))}
+  
+   	if(!is.null(object$fa$RMSEA)) {cat("\nRMSEA index = ",round(object$fa$RMSEA[1],digits+1), " and the", (1- object$fa$RMSEA[4])*100,"% confidence intervals are ",round(object$fa$RMSEA[2:3],digits+1))  }
+   
+   	if(!is.null(object$fa$BIC)) {cat("\nBIC = ",round(object$fa$BIC,digits))}
+    if(!is.null(object$fa$Phi)) {
+   if(object$fa$fn == "principal") {cat ("\n With component correlations of \n" ) } else {cat ("\n With factor correlations of \n" )}
+       colnames(object$fa$Phi) <- rownames(object$fa$Phi) <- colnames(object$fa$loadings)
+       print(round(object$fa$Phi,digits))}
+}
 invisible(result)
    }
   
